ApplePayConfiguration class

Represents the configuration for Apple Pay within the MoneyHash SDK.

Constructors

ApplePayConfiguration({List<CollectibleBillingData>? collectibleBillingData, required String merchantDisplayName})
Creates a new ApplePayConfiguration instance with the specified billing data types to collect and a merchant display name.

Properties

collectibleBillingData → List<CollectibleBillingData>?
The types of billing data that can be collected via Apple Pay.
final
hashCode → int
The hash code for this object.
no setterinherited
merchantDisplayName → String
The merchant display name that will appear within Apple Pay’s payment sheet.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this ApplePayConfiguration into a JSON map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultConfiguration ↔ ApplePayConfiguration
The default Apple Pay configuration for the MoneyHash SDK.
getter/setter pair