AutomaticReloadPaymentRequest class

Constructors

AutomaticReloadPaymentRequest({required String paymentDescription, required AutomaticReloadPaymentSummaryItem automaticReloadBilling, required String managementURL, String? billingAgreement, String? tokenNotificationURL})
AutomaticReloadPaymentRequest.fromJson(dynamic data)
factory

Properties

automaticReloadBilling → AutomaticReloadPaymentSummaryItem
final
billingAgreement → String?
final
hashCode → int
The hash code for this object.
no setterinherited
managementURL → String
final
paymentDescription → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenNotificationURL → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited