cardHolderValidations property

Map<String, String> cardHolderValidations
final

A map of custom validation rules for the card holder name field. The key represents the error message to display when validation fails, and the value represents the regex pattern string.

Example:

{
  "Card holder name must contain only letters and spaces": "^[a-zA-Z\\s]+\$",
  "Card holder name must be between 2 and 50 characters": "^.{2,50}\$"
}

Implementation

final Map<String, String> cardHolderValidations;