CardTokenData class

Constructors

CardTokenData({String? bin, String? brand, String? cardHolderName, String? country, String? expiryMonth, String? expiryYear, String? issuer, String? last4, bool? requiresCvv})
CardTokenData.fromJson(dynamic data)
factory

Properties

bin → String?
final
brand → String?
final
cardHolderName → String?
final
country → String?
final
expiryMonth → String?
final
expiryYear → String?
final
hashCode → int
The hash code for this object.
no setterinherited
issuer → String?
final
last4 → String?
final
final
requiresCvv → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited