InputField class

Constructors

InputField({required InputFieldType type, String? name, String? value, String? label, int? maxLength, required bool isRequired, List<OptionItem>? optionsList, Map<String, List<OptionItem>>? optionsMap, String? hint, int? minLength, required bool readOnly, String? dependsOn})
InputField.fromJson(dynamic data)
factory

Properties

dependsOn → String?
final
hashCode → int
The hash code for this object.
no setterinherited
hint → String?
final
isRequired → bool
final
label → String?
final
maxLength → int?
final
minLength → int?
final
name → String?
final
optionsList → List<OptionItem>?
final
optionsMap → Map<String, List<OptionItem>>?
final
readOnly → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → InputFieldType
final
value ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited