InstallmentPlan class

Constructors

InstallmentPlan({String? id, int? installmentPeriod, double? interestRate, AmountData? amount, double? upfrontFees, String? issuerCode, String? issuerNameEn, String? issuerNameAr, String? issuerLogoAr, String? issuerLogoEn, String? processingFeesType, String? processingFeesAmount, String? feeDisplayValue})
InstallmentPlan.fromJson(dynamic data)
factory

Properties

amount → AmountData?
final
feeDisplayValue → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
installmentPeriod → int?
final
interestRate → double?
final
issuerCode → String?
final
issuerLogoAr → String?
final
issuerLogoEn → String?
final
issuerNameAr → String?
final
issuerNameEn → String?
final
processingFeesAmount → String?
final
processingFeesType → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upfrontFees → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited