IntentData class

Constructors

IntentData({AmountData? amount, String? secret, String? expirationDate, bool? isLive, String? id, IntentStatus? status, List<FeeItem>? fees, String? totalDiscount, String? subtotalAmount})
IntentData.fromJson(dynamic data)
factory

Properties

amount → AmountData?
final
expirationDate → String?
final
fees → List<FeeItem>?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
isLive → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secret → String?
final
status → IntentStatus?
final
subtotalAmount → String?
final
totalDiscount → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited