OperationStatusData class

Constructors

OperationStatusData({String? id, String? value, String? code, String? message, String? localizedMessage, String? providerErrorCode, String? providerErrorMessage, String? created})
OperationStatusData.fromJson(dynamic data)
factory

Properties

code → String?
final
created → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
localizedMessage → String?
A localized, user-friendly message safe to show to end-users (e.g. "Transaction declined by the bank.").
final
message → String?
final
providerErrorCode → String?
The provider-specific error code, when available (e.g. "20151").
final
providerErrorMessage → String?
The provider-specific error message, when available.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited