localizedResponseMessage property
The localized, user-friendly message of the latest operation status, safe to show to end-users (e.g. "Transaction declined by the bank.").
Implementation
final String? localizedResponseMessage;
The localized, user-friendly message of the latest operation status, safe to show to end-users (e.g. "Transaction declined by the bank.").
final String? localizedResponseMessage;