operations property

List<TransactionOperationData>? operations
final

The operations (e.g. purchase, refund) carried out for this transaction, each with its status history. For failed payments, the decline reason is available via operations.first.latestStatus.localizedMessage / providerErrorCode.

Implementation

final List<TransactionOperationData>? operations;