responseCode property
The status code of the latest operation status (e.g. "7151"), for convenience.
Implementation
final String? responseCode;
The status code of the latest operation status (e.g. "7151"), for convenience.
final String? responseCode;