responseMessage property
The message of the latest operation status, for convenience (e.g. "Authentication process for the transaction failed.").
Implementation
final String? responseMessage;
The message of the latest operation status, for convenience (e.g. "Authentication process for the transaction failed.").
final String? responseMessage;