latestStatus property
The most recent status entry, carrying the decline reason for failed operations.
Implementation
final OperationStatusData? latestStatus;
The most recent status entry, carrying the decline reason for failed operations.
final OperationStatusData? latestStatus;