CustomerBalance class

Constructors

CustomerBalance({double? balance, String? id, String? icon, bool? isSelected, MethodType? type})
CustomerBalance.fromJson(dynamic data)
factory

Properties

balance → double?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → String?
final
id → String?
final
isSelected → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → MethodType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited