IntentMethods class

Constructors

IntentMethods({List<CustomerBalance>? customerBalances, List<PaymentMethod>? paymentMethods, List<ExpressMethod>? expressMethods, List<SavedCard>? savedCards, List<PayoutMethod>? payoutMethods, List<SavedBankAccount>? savedBankAccounts})
IntentMethods.fromJson(dynamic data)
factory

Properties

customerBalances → List<CustomerBalance>?
final
expressMethods → List<ExpressMethod>?
final
hashCode → int
The hash code for this object.
no setterinherited
paymentMethods → List<PaymentMethod>?
final
payoutMethods → List<PayoutMethod>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
savedBankAccounts → List<SavedBankAccount>?
final
savedCards → List<SavedCard>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited