PaymentMethod class

Constructors

PaymentMethod({String? id, String? title, bool? isSelected, bool? confirmationRequired, List<String>? icons, MethodType? type, List<InputField>? requiredBillingData, List<InputField>? requiredShippingData})
PaymentMethod.fromJson(dynamic data)
factory

Properties

confirmationRequired → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
icons → List<String>?
final
id → String?
final
isSelected → bool?
final
requiredBillingData → List<InputField>?
final
requiredShippingData → List<InputField>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final
type → MethodType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited