SavedCard class

Constructors

SavedCard({String? id, String? brand, String? last4, String? expiryMonth, String? expiryYear, String? country, bool? requireCvv, CvvConfig? cvvConfig, MethodType? type, String? bin})
SavedCard.fromJson(dynamic data)
factory

Properties

bin → String?
final
brand → String?
final
country → String?
final
cvvConfig → CvvConfig?
final
expiryMonth → String?
final
expiryYear → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
last4 → String?
final
final
requireCvv → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → MethodType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited