FormFields class

Inheritance
Available extensions

Constructors

FormFields({TokenizeCardInfo? tokenizeCardInfo, List<InputField>? billingFields, List<InputField>? shippingFields})

Properties

billingFields → List<InputField>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingFields → List<InputField>?
final
tokenizeCardInfo → TokenizeCardInfo?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited