LastUsedMethod class

Constructors

LastUsedMethod({String? id, LastUsedMethodType? type})
const
LastUsedMethod.fromJson(dynamic data)
Creates a LastUsedMethod from a dynamic JSON-like object.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → LastUsedMethodType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this LastUsedMethod into a JSON map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited