ApplePayData class

Inheritance
Available extensions

Constructors

ApplePayData({String? countryCode, String? merchantId, String? currencyCode, double? amount, String? methodID, List<String>? supportedNetworks, List<String>? merchantCapabilities})
ApplePayData.fromJson(dynamic data)
factory

Properties

amount → double?
final
countryCode → String?
final
currencyCode → String?
final
hashCode → int
The hash code for this object.
no setterinherited
merchantCapabilities → List<String>?
final
merchantId → String?
final
methodID → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedNetworks → List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited