GooglePayData class

Inheritance
Available extensions

Constructors

GooglePayData({String? countryCode, String? merchantId, String? merchantName, String? currencyCode, double? amount, String? gateway, String? gatewayMerchantId, List<String>? allowedCardNetworks, List<String>? allowedCardAuthMethods})
GooglePayData.fromJson(dynamic data)
factory

Properties

allowedCardAuthMethods → List<String>?
final
allowedCardNetworks → List<String>?
final
amount → double?
final
countryCode → String?
final
currencyCode → String?
final
gateway → String?
final
gatewayMerchantId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
merchantId → String?
final
merchantName → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited