RecurringPaymentRequest class

Constructors

RecurringPaymentRequest({required String paymentDescription, required RecurringPaymentSummaryItem regularBilling, required String managementURL, RecurringPaymentSummaryItem? trialBilling, String? billingAgreement, String? tokenNotificationURL})
RecurringPaymentRequest.fromJson(dynamic data)
factory

Properties

billingAgreement String?
final
hashCode int
The hash code for this object.
no setterinherited
managementURL String
final
paymentDescription String
final
regularBilling RecurringPaymentSummaryItem
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokenNotificationURL String?
final
trialBilling RecurringPaymentSummaryItem?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited