SavedBankAccount class

SavedBankAccount represents a saved bank account method.

Use Cases:

  • Managing and displaying saved bank account information.
  • Allowing users to select from previously saved bank account methods.

Constructors

SavedBankAccount({String? id, String? bankIdentifier, BankAccountStatus? status, List<Account>? accounts, String type = 'savedBankAccount', String? title, bool? isSelected, List<String>? checkoutIcons})
SavedBankAccount.fromJson(dynamic data)
factory

Properties

accounts List<Account>?
An array of accounts associated with this saved bank account.
final
bankIdentifier String?
The bank identifier or code.
final
checkoutIcons List<String>?
An array of icons associated with the saved bank account method.
final
hashCode int
The hash code for this object.
no setterinherited
id String?
The unique identifier for the saved bank account.
final
isSelected bool?
A boolean indicating whether the saved bank account method is selected.
final
The logo URL or identifier for the bank.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status BankAccountStatus?
The status of the saved bank account.
final
title String?
The title or name of the saved bank account method.
final
type String
The type of the method, set to "savedBankAccount".
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited