SubscriptionPlanGroupsResponse class

Response containing subscription plan groups with pagination information.

Constructors

SubscriptionPlanGroupsResponse({int? count, bool? hasNext, bool? hasPrevious, List<SubscriptionPlanGroup>? planGroups})
const
SubscriptionPlanGroupsResponse.fromJson(dynamic data)
Create a SubscriptionPlanGroupsResponse from JSON.
factory

Properties

count → int?
Total number of plan groups.
final
hashCode → int
The hash code for this object.
no setterinherited
hasNext → bool?
Indicates whether there are more results available.
final
hasPrevious → bool?
Indicates whether there are previous results available.
final
planGroups → List<SubscriptionPlanGroup>?
List of subscription plan groups.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert this object to JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited