VaultData class

Constructors

VaultData({String? firstSixDigits, String? firstEightDigits, String? lastFourDigits, String? cardScheme, String? cardHolderName, String? expiryYear, String? expiryMonth, bool? isLive, String? accessToken, String? cardToken, String? cvv, bool? saveCard, String? fingerprint})
VaultData.fromJson(dynamic data)
factory

Properties

accessToken → String?
final
cardHolderName → String?
final
cardScheme → String?
final
cardToken → String?
final
cvv → String?
final
expiryMonth → String?
final
expiryYear → String?
final
fingerprint → String?
final
firstEightDigits → String?
final
firstSixDigits → String?
final
hashCode → int
The hash code for this object.
no setterinherited
isLive → bool?
final
lastFourDigits → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saveCard → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited