LogSourceExtension extension
- on
Properties
- value → String
-
Available on LogSource, provided by the LogSourceExtension extension
The name the shared logger knows this source by.no setter
Available on LogSource, provided by the LogSourceExtension extension
The name the shared logger knows this source by.