EmbedButtonStyle class

Available extensions

Properties

base → EmbedButtonViewStyle?
final
focus → EmbedButtonViewStyle?
final
hashCode → int
The hash code for this object.
no setterinherited
hover → EmbedButtonViewStyle?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>

Available on EmbedButtonStyle, provided by the EmbedButtonStyleExtension extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited