EmbedButtonViewStyle class

Available extensions

Constructors

EmbedButtonViewStyle({String? color, String? fontFamily, String? fontWeight, String? fontSize, String? fontSmoothing, String? lineHeight, String? textTransform, String? letterSpacing, String? background, String? padding, String? borderRadius, String? boxShadow, String? borderStyle, String? borderColor, String? borderWidth})

Properties

background → String?
final
borderColor → String?
final
borderRadius → String?
final
borderStyle → String?
final
borderWidth → String?
final
boxShadow → String?
final
color → String?
final
fontFamily → String?
final
fontSize → String?
final
fontSmoothing → String?
final
fontWeight → String?
final
hashCode → int
The hash code for this object.
no setterinherited
letterSpacing → String?
final
lineHeight → String?
final
padding → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textTransform → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>

Available on EmbedButtonViewStyle, provided by the EmbedButtonViewStyleExtension extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited