EmbedInputStyle class

Available extensions

Properties

base → EmbedInputViewStyle?
final
error → EmbedInputViewStyle?
final
focus → EmbedInputViewStyle?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>

Available on EmbedInputStyle, provided by the EmbedInputStyleExtension extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited