EmbedLoaderStyle class

Available extensions

Constructors

EmbedLoaderStyle({String? backgroundColor, String? color})

Properties

backgroundColor → String?
final
color → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>

Available on EmbedLoaderStyle, provided by the EmbedLoaderStyleExtension extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited