EmbedStyle class

Available extensions

Constructors

EmbedStyle({EmbedButtonStyle? submitButton, EmbedLoaderStyle? loader, EmbedInputStyle? input})

Properties

hashCode → int
The hash code for this object.
no setterinherited
input → EmbedInputStyle?
final
loader → EmbedLoaderStyle?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
submitButton → EmbedButtonStyle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>

Available on EmbedStyle, provided by the EmbedStyleExtension extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited