TransactionData class
Constructors
-
TransactionData({String? billingData, double? amount, List<
String> ? externalActionMessage, String? amountCurrency, String? id, String? methodName, String? method, String? createdDate, String? status, String? customFields, String? providerTransactionFields, String? customFormAnswers, List<TransactionOperationData> ? operations, String? responseCode, String? responseMessage, String? localizedResponseMessage}) - TransactionData.fromJson(dynamic data)
-
factory
Properties
- amount → double?
-
final
- amountCurrency → String?
-
final
- billingData → String?
-
final
- createdDate → String?
-
final
- customFields → String?
-
final
- customFormAnswers → String?
-
final
-
externalActionMessage
→ List<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- localizedResponseMessage → String?
-
The localized, user-friendly message of the latest operation status, safe to show
to end-users (e.g. "Transaction declined by the bank.").
final
- method → String?
-
final
- methodName → String?
-
final
-
operations
→ List<
TransactionOperationData> ? -
The operations (e.g. purchase, refund) carried out for this transaction, each with
its status history. For failed payments, the decline reason is available via
operations.first.latestStatus.localizedMessage/providerErrorCode.final - providerTransactionFields → String?
-
final
- responseCode → String?
-
The status code of the latest operation status (e.g. "7151"), for convenience.
final
- responseMessage → String?
-
The message of the latest operation status, for convenience
(e.g. "Authentication process for the transaction failed.").
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited