RecurringPaymentSummaryItem class
Constructors
- RecurringPaymentSummaryItem({required String label, double? amount, DateTime? startDate, DateTime? endDate, int? intervalCount, IntervalUnit? intervalUnit})
- RecurringPaymentSummaryItem.fromJson(dynamic data)
-
factory
Properties
- amount → double?
-
final
- endDate → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- intervalCount → int?
-
final
- intervalUnit → IntervalUnit?
-
final
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited